@@ -4,14 +4,14 @@
 # FILE    : nlp
 # PROJECT : funfunc
 # IDE     : PyCharm
-import re as _re
+import re
 
 
 class Validator:
 
     @classmethod
     def is_url(cls, url_string) -> bool:
-        pat = _re.compile(r"^(http|https)://[0-9a-zA-Z.]*")
+        pat = re.compile(r"^(http|https)://[0-9a-zA-Z.]*")
         if pat.match(url_string):
             return True
         else:
